@@ -5,7 +5,7 @@ from src import settings
 from .object_def.event import Event
 
 
-def creates_batchs(batchs):
+def creates_batchs(batchs) -> None:
     # jobs
     for batch in batchs:
         event = Event(batch, settings.APP_DIR + "/jobs/")
