@@ -2,9 +2,9 @@
 
 import os
 
-from src.models.object_def.a_field import AField
+from src.models._base_def import AField
 
-def creates_buttons(buttons, obj_dir):
+def creates_buttons(buttons, obj_dir) -> None:
     path = "{}/buttons".format(obj_dir)
     if not os.path.exists(path.encode('utf-8')):
         os.makedirs(path.encode('utf-8'))
