@@ -1,9 +1,9 @@
 # process.py
 
 import os
-from src.models.object_def.a_field import AField
+from src.models._base_def import AField
 
-def creates_processes(processes, obj_dir):
+def creates_processes(processes, obj_dir) -> None:
     path = "{}/processes".format(obj_dir)
     if not os.path.exists(path.encode("utf-8")):
         os.makedirs(path.encode("utf-8"))
