@@ -1,6 +1,6 @@
 # relationship.py
 
-def creates_relationships(relations, obj_dir):
+def creates_relationships(relations, obj_dir) -> None:
         # fichier des relations
         file = open("{}/RELATIONSHIP.md".format(obj_dir), 'w+', encoding='utf-8')
         with file:
