@@ -1,7 +1,7 @@
 # workflow.py
 
 
-def creates_workflow(worflows, dir):
+def creates_workflow(worflows, dir) -> None:
     t = open("{}/NODE.md".format(dir), "w+", encoding="utf-8")
     with t:
         t.write("\n## Node in workflow :\n")
