@@ -72,6 +72,21 @@ def parse_xml(xml) -> None:
     if hasattr(app_tree.Application, "CustomLogo"):
         from src.models.logo import creates_logo
         creates_logo(app_tree.Application.CustomLogo.cdata, app_tree.Application.Props.appLogo.cdata)
+        
+    # PostInstallScriptB64
+    if hasattr(app_tree.Application, "PostInstallScriptB64"):
+        from src.models.install_script import creates_install_script
+        creates_install_script(app_tree.Application.PostInstallScriptB64.cdata, "post_install_script")
+    
+    # PostAppInstallScriptB64
+    if hasattr(app_tree.Application, "PostAppInstallScriptB64"):
+        from src.models.install_script import creates_install_script
+        creates_install_script(app_tree.Application.PostAppInstallScriptB64.cdata, "post_app_install_script")
+        
+    # PostAppUpdateScriptB64
+    if hasattr(app_tree.Application, "PostAppUpdateScriptB64"):
+        from src.models.install_script import creates_install_script
+        creates_install_script(app_tree.Application.PostAppUpdateScriptB64.cdata, "post_update_script")
     
     # creates application Dependent Object
     if hasattr(app_tree.Application, "DependentDefs"):
